@@ -7,9 +7,9 @@ use warnings;
 use PerlX::Maybe;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-06-05'; # DATE
+our $DATE = '2023-01-27'; # DATE
 our $DIST = 'App-td'; # DIST
-our $VERSION = '0.107'; # VERSION
+our $VERSION = '0.108'; # VERSION
 
 our %SPEC;
 
@@ -235,7 +235,7 @@ Next, you can use these actions:
     % osnames -l --json | td select value description
 
     # Select all columns but some
-    % osnames -l --json | td select '*' -e value -e description
+    % osnames -l --json | td select '*' -E value -E description
 
     # Return the rows in a random order
     % osnames -l --json | td shuf
@@ -265,14 +265,14 @@ Next, you can use these actions:
     % command ... | td uniq -i ;# case-insensitive
     % command ... | td uniq --repeated ;# only shows the duplicate rows
     % command ... | td uniq -i C1 -i C2 ;# only use columns C1 & C2 to check uniqueness
-    % command ... | td uniq -e C5 -e C6 ;# use all columns but C5 & C6 to check uniqueness
+    % command ... | td uniq -E C5 -E C6 ;# use all columns but C5 & C6 to check uniqueness
 
     # Remove non-adjacent duplicate rows:
     % command ... | td nauniq
     % command ... | td nauniq -i ;# case-insensitive
     % command ... | td nauniq --repeated ;# only shows the duplicate rows
     % command ... | td nauniq -i C1 -i C2 ;# only use columns C1 & C2 to check uniqueness
-    % command ... | td nauniq -e C5 -e C6 ;# use all columns but C5 & C6 to check uniqueness
+    % command ... | td nauniq -E C5 -E C6 ;# use all columns but C5 & C6 to check uniqueness
 
     # Transpose table (make first column of rows as column names in the
     # transposed table)
@@ -900,7 +900,7 @@ App::td - Manipulate table data
 
 =head1 VERSION
 
-This document describes version 0.107 of App::td (from Perl distribution App-td), released on 2022-06-05.
+This document describes version 0.108 of App::td (from Perl distribution App-td), released on 2023-01-27.
 
 =head1 FUNCTIONS
 
@@ -1011,7 +1011,7 @@ Next, you can use these actions:
  % osnames -l --json | td select value description
  
  # Select all columns but some
- % osnames -l --json | td select '*' -e value -e description
+ % osnames -l --json | td select '*' -E value -E description
  
  # Return the rows in a random order
  % osnames -l --json | td shuf
@@ -1041,14 +1041,14 @@ Next, you can use these actions:
  % command ... | td uniq -i ;# case-insensitive
  % command ... | td uniq --repeated ;# only shows the duplicate rows
  % command ... | td uniq -i C1 -i C2 ;# only use columns C1 & C2 to check uniqueness
- % command ... | td uniq -e C5 -e C6 ;# use all columns but C5 & C6 to check uniqueness
+ % command ... | td uniq -E C5 -E C6 ;# use all columns but C5 & C6 to check uniqueness
  
  # Remove non-adjacent duplicate rows:
  % command ... | td nauniq
  % command ... | td nauniq -i ;# case-insensitive
  % command ... | td nauniq --repeated ;# only shows the duplicate rows
  % command ... | td nauniq -i C1 -i C2 ;# only use columns C1 & C2 to check uniqueness
- % command ... | td nauniq -e C5 -e C6 ;# use all columns but C5 & C6 to check uniqueness
+ % command ... | td nauniq -E C5 -E C6 ;# use all columns but C5 & C6 to check uniqueness
  
  # Transpose table (make first column of rows as column names in the
  # transposed table)
@@ -1102,20 +1102,31 @@ Arguments ('*' denotes required arguments):
 
 Action to perform on input table.
 
+
 =item * B<argv> => I<array[str]> (default: [])
 
 Arguments.
 
 =item * B<case_insensitive> => I<true>
 
+(No description)
+
 =item * B<detail> => I<bool>
 
+(No description)
+
 =item * B<exclude_columns> => I<array[str]>
 
+(No description)
+
 =item * B<include_columns> => I<array[str]>
 
+(No description)
+
 =item * B<lines> => I<str>
 
+(No description)
+
 =item * B<no_header_column> => I<true>
 
 Don't make the first column as column names of the transposed table; instead create column named 'row1', 'row2', ...
@@ -1192,13 +1203,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2021, 2020, 2019, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2021, 2020, 2019, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
